//--------------------------------------------------------------
// Press F1 to get help about using script.
// To access an object that is not located in the current class, start the call with Globals.
// When using events and timers be cautious not to generate memoryleaks,
// please see the help for more information.
//---------------------------------------------------------------

/*
	*******************************************************************
	All examples in this support document are only intended
	to improve understanding of the functionality and 
	handling of the equipment. 
	Beijer Electronics AB cannot assume any liability if these
	examples are used in real applications.
	In view of the wide range of applications for this 
	equipment, users must acquire sufficient knowledge 
	themselves in order to ensure that it is correctly used in 
	their specific application. Persons responsible for the 
	application and the equipment must themselves 
	ensure that each application is in compliance with all 
	relevant requirements, standards and legislation in 
	respect to configuration and safety.
	Beijer Electronics AB will accept no liability for any 
	damage incurred during the installation or use of this 
	equipment.
	Beijer Electronics AB prohibits all modification, changes
	or conversion of the equipment.
	*******************************************************************

	Revision 2017-03-2+ SNL: Changed to SQLite (necessary for iX 2.20 forward)
	*/

namespace Neo.ApplicationFramework.Generated
{
    using System.Windows.Forms;
    using System;
    using System.Drawing;
    using Neo.ApplicationFramework.Tools;
    using Neo.ApplicationFramework.Common.Graphics.Logic;
    using Neo.ApplicationFramework.Controls;
    using Neo.ApplicationFramework.Interfaces;
    
	using System.Data;
	using System.Data.SQLite;
	using System.IO;
	using System.Reflection;

    public partial class AlarmStatistics
    {
	
		//private SqlCeConnection m_SqlConnection;
		private SQLiteConnection m_SqlConnection;

		/// <summary>
		/// Counts the number of alarms with a certain status
		/// </summary>
		/// <param name="AlarmGroupName">The name of the Alarm group to count alarms from</param>
		/// <param name="AlarmStatus">The state to match, useful state strings are "Active", "Inactive" and "Normal"</param>
		/// <returns>The number of alarms or a negative number if an error occured.</returns>
		public int NumberOfAlarms(string AlarmGroupName, string AlarmStatus)
		{
			int CountedStatus = 0;
			DataSet dataSet = null;								// Variable to hold data set.
			if (ConnectToDataBase())							// If connection is ok.
			{
				try 											// in case of problems
				{	
					// Create SQL query, ask database, fetch data and fill data set
					string sqlString = string.Format("SELECT State , COUNT(*) FROM AlarmServer WHERE AlarmItemName LIKE '{0}%' AND State = '{1}' GROUP BY State",AlarmGroupName,AlarmStatus);
					SQLiteDataAdapter SQLiteDataAdapter = new SQLiteDataAdapter(sqlString, m_SqlConnection);
					dataSet = new DataSet();
					SQLiteDataAdapter.Fill(dataSet);
				}
				catch //(SqlCeException)
				{
					CountedStatus = 0;
				}				
			}
			DisconnectFromDataBase();							// Disconnect and free memory						
			if (dataSet != null && dataSet.Tables != null)		// If we got stuff, do tell.
			{
				try
				{
					// If there is a result from the query, the number is int table zero, on row zero, cell one.
					CountedStatus = Convert.ToInt32(dataSet.Tables[0].Rows[0].ItemArray[1]);
				}
				catch
				{
					CountedStatus = 0;
				}
			}
			else												// Otherwise return error code 
			{
				CountedStatus = 0;				
			}						
			return CountedStatus;
		}
		
		
		/// <summary>
		/// Get the path to where the project is excecuting.
		/// This differs if you run the project from the pc
		/// or in the terminal.
		/// </summary>
		private string ExecutingPath
		{
			get { return Path.GetDirectoryName(Assembly.GetExecutingAssembly().ManifestModule.FullyQualifiedName); }
		}
		
		/// <summary>
		/// Tries to connect to the database.
		/// </summary>
		/// <returns>True if successful, otherwise false.</returns>
		private bool ConnectToDataBase()
		{
			// Checks if there already is an active connection. 
			// If so, it returns true right away.
			if (m_SqlConnection != null && m_SqlConnection.State == ConnectionState.Open)
				return true;

			// Create a new sql connection object.
			m_SqlConnection = new SQLiteConnection();
			// Specify the connectionstring, with the full path to the database.
			m_SqlConnection.ConnectionString = string.Format("data source={0}", Path.Combine(ExecutingPath, "Database.db"));

			// Using a try/catch in case something goes wrong.
			// Should the full path to the database be wrong, it will throw an exception.
			// This prevents the termination of the program.
			try 
			{
				// Tries to open the connection.
				m_SqlConnection.Open();
			}
			catch //(SqlCeException)
			{
				// If it went wrong, terminate the connection completely.
				DisconnectFromDataBase();
				// Return false to indicate that the connection couldn't be made.
				return false;
			}

			// Checks the state of the connection, returning true if it is open.
			return m_SqlConnection.State == ConnectionState.Open;
		}

		/// <summary>
		/// Disconnects from the database and disposes the connection.
		/// </summary>
		private void DisconnectFromDataBase()
		{
			// Makes sure that the connection isn't already disposed.
			if (m_SqlConnection != null)
			{
				// Checks to see if the connection is open.
				if(m_SqlConnection.State == ConnectionState.Open)
				{
					// Close the connection.
					m_SqlConnection.Close();
				}
				// Dispose the connection object.
				m_SqlConnection.Dispose();
				// Set it to null, so that it is easy to find out
				// if it is in use or not.
				m_SqlConnection = null;
			}
		}
    }
}
